==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/WinRMConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes Windows Remote Management configuration of the VM
 * @property listeners The list of Windows Remote Management listeners
 */
public data class WinRMConfigurationArgs(
    public val listeners: Output<List<WinRMListenerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs.builder()
            .listeners(
                listeners?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WinRMConfigurationArgs].
 */
@PulumiTagMarker
public class WinRMConfigurationArgsBuilder internal constructor() {
    private var listeners: Output<List<WinRMListenerArgs>>? = null

    /**
     * @param value The list of Windows Remote Management listeners
     */
    @JvmName("wjjkpplcsyveugsf")
    public suspend fun listeners(`value`: Output<List<WinRMListenerArgs>>) {
        this.listeners = value
    }

    @JvmName("hqvmvwflqnedvuoo")
    public suspend fun listeners(vararg values: Output<WinRMListenerArgs>) {
        this.listeners = Output.all(values.asList())
    }

    /**
     * @param values The list of Windows Remote Management listeners
     */
    @JvmName("pctgiykxevrdnacd")
    public suspend fun listeners(values: List<Output<WinRMListenerArgs>>) {
        this.listeners = Output.all(values)
    }

    /**
     * @param value The list of Windows Remote Management listeners
     */
    @JvmName("eoouxgqjcrveikxq")
    public suspend fun listeners(`value`: List<WinRMListenerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.listeners = mapped
    }

    /**
     * @param argument The list of Windows Remote Management listeners
     */
    @JvmName("eqnodgllmckcyhdp")
    public suspend fun listeners(argument: List<suspend WinRMListenerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WinRMListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.listeners = mapped
    }

    /**
     * @param argument The list of Windows Remote Management listeners
     */
    @JvmName("xilxkgdnhuhcdagh")
    public suspend fun listeners(vararg argument: suspend WinRMListenerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            WinRMListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.listeners = mapped
    }

    /**
     * @param argument The list of Windows Remote Management listeners
     */
    @JvmName("wabdjsdinccperud")
    public suspend fun listeners(argument: suspend WinRMListenerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WinRMListenerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.listeners = mapped
    }

    /**
     * @param values The list of Windows Remote Management listeners
     */
    @JvmName("lkkwlehlaguttfdr")
    public suspend fun listeners(vararg values: WinRMListenerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.listeners = mapped
    }

    internal fun build(): WinRMConfigurationArgs = WinRMConfigurationArgs(
        listeners = listeners,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/WinRMConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes Windows Remote Management configuration of the VM
 * @property listeners The list of Windows Remote Management listeners
 */
public data class WinRMConfigurationArgs(
    public val listeners: Output<List<WinRMListenerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.WinRMConfigurationArgs.builder()
            .listeners(
                listeners?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WinRMConfigurationArgs].
 */
@PulumiTagMarker
public class WinRMConfigurationArgsBuilder internal constructor() {
    private var listeners: Output<List<WinRMListenerArgs>>? = null

    /**
     * @param value The list of Windows Remote Management listeners
     */
    @JvmName("jbbjusntpwhwwaok")
    public suspend fun listeners(`value`: Output<List<WinRMListenerArgs>>) {
        this.listeners = value
    }

    @JvmName("uailpsqfpmxkkatq")
    public suspend fun listeners(vararg values: Output<WinRMListenerArgs>) {
        this.listeners = Output.all(values.asList())
    }

    /**
     * @param values The list of Windows Remote Management listeners
     */
    @JvmName("yoadsxiofbyctnxa")
    public suspend fun listeners(values: List<Output<WinRMListenerArgs>>) {
        this.listeners = Output.all(values)
    }

    /**
     * @param value The list of Windows Remote Management listeners
     */
    @JvmName("tovtqkwfiypmhncr")
    public suspend fun listeners(`value`: List<WinRMListenerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.listeners = mapped
    }

    /**
     * @param argument The list of Windows Remote Management listeners
     */
    @JvmName("pxrxrynmrvuijcya")
    public suspend fun listeners(argument: List<suspend WinRMListenerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WinRMListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.listeners = mapped
    }

    /**
     * @param argument The list of Windows Remote Management listeners
     */
    @JvmName("chdypkojmitvsanq")
    public suspend fun listeners(vararg argument: suspend WinRMListenerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            WinRMListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.listeners = mapped
    }

    /**
     * @param argument The list of Windows Remote Management listeners
     */
    @JvmName("hiouttcbsbkxwrpx")
    public suspend fun listeners(argument: suspend WinRMListenerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WinRMListenerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.listeners = mapped
    }

    /**
     * @param values The list of Windows Remote Management listeners
     */
    @JvmName("yhvkkruxmthaokdj")
    public suspend fun listeners(vararg values: WinRMListenerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.listeners = mapped
    }

    internal fun build(): WinRMConfigurationArgs = WinRMConfigurationArgs(
        listeners = listeners,
    )
}
